@@ -25,7 +25,7 @@ Rcpp::NumericVector read_date(vroom_vec_info* info) {
       n,
       [&](size_t start, size_t end, size_t id) {
         auto i = start;
-        DateTimeParser parser(&*info->locale);
+        DateTimeParser parser(info->locale.get());
         auto col = info->column->slice(start, end);
         for (const auto& str : *col) {
           out[i++] = parse_date(str, parser, info->format);
