@@ -8,6 +8,8 @@
 #include "connection.h"
 #include "r_utils.h"
 
+#include "unicode_fopen.h"
+
 typedef enum {
   quote_needed = 1,
   quote_all = 2,
@@ -316,7 +318,7 @@ void vroom_write_(
     strcpy(mode, "ab");
   }
 
-  std::FILE* out = std::fopen(filename.c_str(), mode);
+  std::FILE* out = unicode_fopen(filename.c_str(), mode);
   if (!out) {
     std::string msg("Cannot open file for writing:\n* ");
     msg += '\'' + filename + '\'';
@@ -405,7 +407,13 @@ void vroom_write_connection_(
     size_t num_threads,
     bool progress,
     size_t buf_lines,
-    bool is_stdout) {
+    bool is_stdout,
+    bool append) {
+
+  char mode[3] = "wb";
+  if (append) {
+    strcpy(mode, "ab");
+  }
 
   size_t begin = 0;
   size_t num_rows = Rf_xlength(input[0]);
@@ -414,7 +422,7 @@ void vroom_write_connection_(
 
   bool should_open = !is_open(con);
   if (should_open) {
-    Rcpp::as<Rcpp::Function>(Rcpp::Environment::base_env()["open"])(con, "wb");
+    Rcpp::as<Rcpp::Function>(Rcpp::Environment::base_env()["open"])(con, mode);
   }
 
   bool should_close = should_open;
